Skip to contents

This function takes an R value and converts it to its corresponding database representation. It handles different data types such as Date, NA, character, and others.

Usage

R_value_to_db_value(r_value, force_type = "")

Arguments

r_value

An R value to be converted.

force_type

An optional string specifying the database type to force for NULL values.

Value

A string representing the database value.