Skip to contents

Changes the password for a user in the Seatrack database. Since the passwords for the file archive are fetched from the database, this also affects the file archive.

Usage

changeSeatrackPassword(password = NULL)

Arguments

password

Your new password (character string).

Value

Null

Examples

if (FALSE) { # \dontrun{
changeSeatrackPassword("newPassword")
} # }