Check People String
checkPeople.RdThis function checks if a given people string is valid by calling a database function. It returns TRUE if the string is valid, and FALSE otherwise.
checkPeople.RdThis function checks if a given people string is valid by calling a database function. It returns TRUE if the string is valid, and FALSE otherwise.