viewDatabaseModel.Rd
Zoom in with the browser to see the details
viewDatabaseModel(type = c("png"))
Open the database model in either "png" or "svg".
Opens a internet browser window with the database model.
if (FALSE) { # \dontrun{ viewDatabaseModel() } # }