R_vector_to_db_values.Rd
This function takes an R vector and converts each value to its corresponding database representation.
R_vector_to_db_values(vector, dbtype = "")
An R vector to be converted.
An optional string specifying the database type to force for NULL values.
A string representing the database values.