Check the version of the database Checks the version of the database by querying the flyway_schema_history table. If the table does not exist, it returns 0.
check_db_version.RdCheck the version of the database Checks the version of the database by querying the flyway_schema_history table. If the table does not exist, it returns 0.