Manually update the the materialized views in the database
refreshViews.RdUpdate all or optionally single materialized views in the database. Typically done after data imports.
Usage
refreshViews(
all = TRUE,
onlySummaryTables = FALSE,
onlyGLS = FALSE,
onlyGPS = FALSE,
onlyIrma = FALSE
)Examples
if (FALSE) { # \dontrun{
connectSeatrack(Username = "testreader", Password = "testreader")
refreshViews()
} # }