Skip to contents

Zoom in with the browser to see the details

Usage

viewDatabaseModel(type = c("png", "svg"))

Arguments

type

Open the database model in either "png" or "svg".

Value

Opens a internet browser window with the database model.

Examples

if (FALSE) { # \dontrun{
viewDatabaseModel()
} # }