Update the positions.postable
writePositions.RdThis is a convenience function that writes to the "positions.postable_raw/gps_raw/irma_raw" table, the main tables for the position data. It then by default updates the views which links up this data to the logger session data in the database.
Examples
if (FALSE) { # \dontrun{
connectSeatrack(Username = "testreader", Password = "testreader")
files <- c(
"posdata_FULGLA_eynhallow_2014",
"posdata_FULGLA_eynhallow_2013",
"posdata_FULGLA_eynhallow_2012",
"posdata_FULGLA_eynhallow_2011",
"posdata_FULGLA_eynhallow_2010",
"posdata_FULGLA_eynhallow_2009",
"posdata_FULGLA_eynhallow_2007"
)
toImport <- loadPosdata(files)
summary(toImport)
writePositions(toImport)
} # }